==> haskell-binary-conduit-1.3-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-conduit
version: 1.3
id: binary-conduit-1.3-G8HraTZ6QOa28xbKSo58uw
key: binary-conduit-1.3-G8HraTZ6QOa28xbKSo58uw
license: MIT
copyright: 2013 Alexander Vershilov
maintainer: alexander.vershilov@gmail.com
author: Alexander Vershilov
stability: Experimental
homepage: http://github.com/qnikst/binary-conduit/
synopsis: data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.
category: Conduit
abi: bac1c15be8ede5d40a008ee871df0b6e
exposed: True
exposed-modules:
    Data.Conduit.Serialization.Binary
import-dirs: /usr/lib/ghc-8.4.3/site-local/binary-conduit-1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/binary-conduit-1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/binary-conduit-1.3
hs-libraries: HSbinary-conduit-1.3-G8HraTZ6QOa28xbKSo58uw
depends:
    base-4.11.1.0 conduit-1.3.0.2-6ggLMYs5PCDHnM0outc1AL
    bytestring-0.10.8.2 binary-0.8.5.1
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             conduit-1.3.0.2-6ggLMYs5PCDHnM0outc1AL=33facae0ae8a68763252a2c9319504f4
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
haddock-interfaces: /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock
haddock-html: /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-conduit-1.3-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-conduit
version: 1.3
id: binary-conduit-1.3-53v2kbkIJk69VX6KwUhG7Y
key: binary-conduit-1.3-53v2kbkIJk69VX6KwUhG7Y
license: MIT
copyright: 2013 Alexander Vershilov
maintainer: alexander.vershilov@gmail.com
author: Alexander Vershilov
stability: Experimental
homepage: http://github.com/qnikst/binary-conduit/
synopsis: data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.
category: Conduit
abi: 7dd2c03a57e290eaf7bc9dc8c873b7ee
exposed: True
exposed-modules:
    Data.Conduit.Serialization.Binary
import-dirs: /usr/lib/ghc-8.4.3/site-local/binary-conduit-1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/binary-conduit-1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/binary-conduit-1.3
hs-libraries: HSbinary-conduit-1.3-53v2kbkIJk69VX6KwUhG7Y
depends:
    base-4.11.1.0 conduit-1.3.0.2-CmpsFFB0CNdJAwBqx2M2rY
    bytestring-0.10.8.2 binary-0.8.5.1
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             conduit-1.3.0.2-CmpsFFB0CNdJAwBqx2M2rY=35973616512ff3a89e26461aa04e9f50
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
haddock-interfaces: /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock
haddock-html: /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
